# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: face.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='face.proto',
  package='face',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.faceP\001Z\024biostar/service/face'),
  serialized_pb=_b('\n\nface.proto\x12\x04\x66\x61\x63\x65\x1a\terr.proto\"w\n\x08\x46\x61\x63\x65\x44\x61ta\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\x12\x11\n\ttemplates\x18\x03 \x03(\x0c\x12\x11\n\timageData\x18\x05 \x01(\x0c\x12\x13\n\x0birTemplates\x18\x07 \x03(\x0c\x12\x13\n\x0birImageData\x18\t \x01(\x0c\"S\n\x0bScanRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x32\n\x0f\x65nrollThreshold\x18\x02 \x01(\x0e\x32\x19.face.FaceEnrollThreshold\"0\n\x0cScanResponse\x12 \n\x08\x66\x61\x63\x65\x44\x61ta\x18\x02 \x01(\x0b\x32\x0e.face.FaceData\"G\n\x0e\x45xtractRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x11\n\timageData\x18\x02 \x01(\x0c\x12\x10\n\x08isWarped\x18\x03 \x01(\x08\"\'\n\x0f\x45xtractResponse\x12\x14\n\x0ctemplateData\x18\x02 \x01(\x0c\"@\n\x10NormalizeRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1a\n\x12unwrappedImageData\x18\x02 \x01(\x0c\"-\n\x11NormalizeResponse\x12\x18\n\x10wrappedImageData\x18\x01 \x01(\x0c\"%\n\tAuthGroup\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"\'\n\x13GetAuthGroupRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\";\n\x14GetAuthGroupResponse\x12#\n\nauthGroups\x18\x01 \x03(\x0b\x32\x0f.face.AuthGroup\"L\n\x13\x41\x64\x64\x41uthGroupRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12#\n\nauthGroups\x18\x02 \x03(\x0b\x32\x0f.face.AuthGroup\"\x16\n\x14\x41\x64\x64\x41uthGroupResponse\"R\n\x18\x41\x64\x64\x41uthGroupMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12#\n\nauthGroups\x18\x02 \x03(\x0b\x32\x0f.face.AuthGroup\"E\n\x19\x41\x64\x64\x41uthGroupMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"<\n\x16\x44\x65leteAuthGroupRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"\x19\n\x17\x44\x65leteAuthGroupResponse\"B\n\x1b\x44\x65leteAuthGroupMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"H\n\x1c\x44\x65leteAuthGroupMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"-\n\x19\x44\x65leteAllAuthGroupRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1c\n\x1a\x44\x65leteAllAuthGroupResponse\"3\n\x1e\x44\x65leteAllAuthGroupMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"K\n\x1f\x44\x65leteAllAuthGroupMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xe0\x02\n\nFaceConfig\x12.\n\rsecurityLevel\x18\x01 \x01(\x0e\x32\x17.face.FaceSecurityLevel\x12\x30\n\x0elightCondition\x18\x02 \x01(\x0e\x32\x18.face.FaceLightCondition\x12\x32\n\x0f\x65nrollThreshold\x18\x03 \x01(\x0e\x32\x19.face.FaceEnrollThreshold\x12\x36\n\x11\x64\x65tectSensitivity\x18\x04 \x01(\x0e\x32\x1b.face.FaceDetectSensitivity\x12\x15\n\renrollTimeout\x18\x05 \x01(\r\x12$\n\x08LFDLevel\x18\x06 \x01(\x0e\x32\x12.face.FaceLFDLevel\x12\x17\n\x0fquickEnrollment\x18\x07 \x01(\x08\x12.\n\rpreviewOption\x18\x08 \x01(\x0e\x32\x17.face.FacePreviewOption\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x11GetConfigResponse\x12 \n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x10.face.FaceConfig\"F\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.face.FaceConfig\"\x13\n\x11SetConfigResponse\"L\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.face.FaceConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*9\n\x08\x46\x61\x63\x65\x46lag\x12\x16\n\x12\x42S2_FACE_FLAG_NONE\x10\x00\x12\x15\n\x10\x42S2_FACE_FLAG_F2\x10\x80\x02*\x95\x01\n\x11\x46\x61\x63\x65SecurityLevel\x12\x1c\n\x18\x42S2_FACE_SECURITY_NORMAL\x10\x00\x12\x1c\n\x18\x42S2_FACE_SECURITY_SECURE\x10\x01\x12!\n\x1d\x42S2_FACE_SECURITY_MORE_SECURE\x10\x02\x12\x1d\n\x19\x42S2_FACE_SECURITY_DEFAULT\x10\x00\x1a\x02\x10\x01*\x8a\x03\n\x13\x46\x61\x63\x65\x45nrollThreshold\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_0\x10\x00\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_1\x10\x01\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_2\x10\x02\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_3\x10\x03\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_4\x10\x04\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_5\x10\x05\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_6\x10\x06\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_7\x10\x07\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_8\x10\x08\x12\x1f\n\x1b\x42S2_FACE_ENROLL_THRESHOLD_9\x10\t\x12%\n!BS2_FACE_ENROLL_THRESHOLD_DEFAULT\x10\x04\x1a\x02\x10\x01*\xcf\x01\n\x12\x46\x61\x63\x65LightCondition\x12#\n\x1f\x42S2_FACE_LIGHT_CONDITION_INDOOR\x10\x00\x12$\n BS2_FACE_LIGHT_CONDITION_OUTDOOR\x10\x01\x12!\n\x1d\x42S2_FACE_LIGHT_CONDITION_AUTO\x10\x02\x12!\n\x1d\x42S2_FACE_LIGHT_CONDITION_DARK\x10\x03\x12$\n BS2_FACE_LIGHT_CONDITION_DEFAULT\x10\x00\x1a\x02\x10\x01*\xdc\x01\n\x15\x46\x61\x63\x65\x44\x65tectSensitivity\x12#\n\x1f\x42S2_FACE_DETECT_SENSITIVITY_OFF\x10\x00\x12#\n\x1f\x42S2_FACE_DETECT_SENSITIVITY_LOW\x10\x01\x12&\n\"BS2_FACE_DETECT_SENSITIVITY_MIDDLE\x10\x02\x12$\n BS2_FACE_DETECT_SENSITIVITY_HIGH\x10\x03\x12\'\n#BS2_FACE_DETECT_SENSITIVITY_DEFAULT\x10\x02\x1a\x02\x10\x01*\xa6\x01\n\x0c\x46\x61\x63\x65LFDLevel\x12\x1a\n\x16\x42S2_FACE_LFD_LEVEL_OFF\x10\x00\x12\x1a\n\x16\x42S2_FACE_LFD_LEVEL_LOW\x10\x01\x12\x1d\n\x19\x42S2_FACE_LFD_LEVEL_MIDDLE\x10\x02\x12\x1b\n\x17\x42S2_FACE_LFD_LEVEL_HIGH\x10\x03\x12\x1e\n\x1a\x42S2_FACE_LFD_LEVEL_DEFAULT\x10\x00\x1a\x02\x10\x01*\x86\x01\n\x11\x46\x61\x63\x65PreviewOption\x12\x19\n\x15\x42S2_FACE_PREVIEW_NONE\x10\x00\x12\x19\n\x15\x42S2_FACE_PREVIEW_HALF\x10\x01\x12\x19\n\x15\x42S2_FACE_PREVIEW_FULL\x10\x02\x12\x1c\n\x18\x42S2_FACE_PREVIEW_DEFAULT\x10\x01\x1a\x02\x10\x01\x32\xc8\x07\n\x04\x46\x61\x63\x65\x12-\n\x04Scan\x12\x11.face.ScanRequest\x1a\x12.face.ScanResponse\x12\x36\n\x07\x45xtract\x12\x14.face.ExtractRequest\x1a\x15.face.ExtractResponse\x12<\n\tNormalize\x12\x16.face.NormalizeRequest\x1a\x17.face.NormalizeResponse\x12<\n\tGetConfig\x12\x16.face.GetConfigRequest\x1a\x17.face.GetConfigResponse\x12<\n\tSetConfig\x12\x16.face.SetConfigRequest\x1a\x17.face.SetConfigResponse\x12K\n\x0eSetConfigMulti\x12\x1b.face.SetConfigMultiRequest\x1a\x1c.face.SetConfigMultiResponse\x12\x45\n\x0cGetAuthGroup\x12\x19.face.GetAuthGroupRequest\x1a\x1a.face.GetAuthGroupResponse\x12\x45\n\x0c\x41\x64\x64\x41uthGroup\x12\x19.face.AddAuthGroupRequest\x1a\x1a.face.AddAuthGroupResponse\x12T\n\x11\x41\x64\x64\x41uthGroupMulti\x12\x1e.face.AddAuthGroupMultiRequest\x1a\x1f.face.AddAuthGroupMultiResponse\x12N\n\x0f\x44\x65leteAuthGroup\x12\x1c.face.DeleteAuthGroupRequest\x1a\x1d.face.DeleteAuthGroupResponse\x12]\n\x14\x44\x65leteAuthGroupMulti\x12!.face.DeleteAuthGroupMultiRequest\x1a\".face.DeleteAuthGroupMultiResponse\x12W\n\x12\x44\x65leteAllAuthGroup\x12\x1f.face.DeleteAllAuthGroupRequest\x1a .face.DeleteAllAuthGroupResponse\x12\x66\n\x17\x44\x65leteAllAuthGroupMulti\x12$.face.DeleteAllAuthGroupMultiRequest\x1a%.face.DeleteAllAuthGroupMultiResponseB1\n\x17\x63om.supremainc.sdk.faceP\x01Z\x14\x62iostar/service/faceb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_FACEFLAG = _descriptor.EnumDescriptor(
  name='FaceFlag',
  full_name='face.FaceFlag',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_FLAG_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_FLAG_F2', index=1, number=256,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2037,
  serialized_end=2094,
)
_sym_db.RegisterEnumDescriptor(_FACEFLAG)

FaceFlag = enum_type_wrapper.EnumTypeWrapper(_FACEFLAG)
_FACESECURITYLEVEL = _descriptor.EnumDescriptor(
  name='FaceSecurityLevel',
  full_name='face.FaceSecurityLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_SECURITY_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_SECURITY_SECURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_SECURITY_MORE_SECURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_SECURITY_DEFAULT', index=3, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=2097,
  serialized_end=2246,
)
_sym_db.RegisterEnumDescriptor(_FACESECURITYLEVEL)

FaceSecurityLevel = enum_type_wrapper.EnumTypeWrapper(_FACESECURITYLEVEL)
_FACEENROLLTHRESHOLD = _descriptor.EnumDescriptor(
  name='FaceEnrollThreshold',
  full_name='face.FaceEnrollThreshold',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_3', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_4', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_5', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_6', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_7', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_8', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_9', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_ENROLL_THRESHOLD_DEFAULT', index=10, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=2249,
  serialized_end=2643,
)
_sym_db.RegisterEnumDescriptor(_FACEENROLLTHRESHOLD)

FaceEnrollThreshold = enum_type_wrapper.EnumTypeWrapper(_FACEENROLLTHRESHOLD)
_FACELIGHTCONDITION = _descriptor.EnumDescriptor(
  name='FaceLightCondition',
  full_name='face.FaceLightCondition',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LIGHT_CONDITION_INDOOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LIGHT_CONDITION_OUTDOOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LIGHT_CONDITION_AUTO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LIGHT_CONDITION_DARK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LIGHT_CONDITION_DEFAULT', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=2646,
  serialized_end=2853,
)
_sym_db.RegisterEnumDescriptor(_FACELIGHTCONDITION)

FaceLightCondition = enum_type_wrapper.EnumTypeWrapper(_FACELIGHTCONDITION)
_FACEDETECTSENSITIVITY = _descriptor.EnumDescriptor(
  name='FaceDetectSensitivity',
  full_name='face.FaceDetectSensitivity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_DETECT_SENSITIVITY_OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_DETECT_SENSITIVITY_LOW', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_DETECT_SENSITIVITY_MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_DETECT_SENSITIVITY_HIGH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_DETECT_SENSITIVITY_DEFAULT', index=4, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=2856,
  serialized_end=3076,
)
_sym_db.RegisterEnumDescriptor(_FACEDETECTSENSITIVITY)

FaceDetectSensitivity = enum_type_wrapper.EnumTypeWrapper(_FACEDETECTSENSITIVITY)
_FACELFDLEVEL = _descriptor.EnumDescriptor(
  name='FaceLFDLevel',
  full_name='face.FaceLFDLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LFD_LEVEL_OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LFD_LEVEL_LOW', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LFD_LEVEL_MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LFD_LEVEL_HIGH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_LFD_LEVEL_DEFAULT', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=3079,
  serialized_end=3245,
)
_sym_db.RegisterEnumDescriptor(_FACELFDLEVEL)

FaceLFDLevel = enum_type_wrapper.EnumTypeWrapper(_FACELFDLEVEL)
_FACEPREVIEWOPTION = _descriptor.EnumDescriptor(
  name='FacePreviewOption',
  full_name='face.FacePreviewOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_PREVIEW_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_PREVIEW_HALF', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_PREVIEW_FULL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_FACE_PREVIEW_DEFAULT', index=3, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=3248,
  serialized_end=3382,
)
_sym_db.RegisterEnumDescriptor(_FACEPREVIEWOPTION)

FacePreviewOption = enum_type_wrapper.EnumTypeWrapper(_FACEPREVIEWOPTION)
BS2_FACE_FLAG_NONE = 0
BS2_FACE_FLAG_F2 = 256
BS2_FACE_SECURITY_NORMAL = 0
BS2_FACE_SECURITY_SECURE = 1
BS2_FACE_SECURITY_MORE_SECURE = 2
BS2_FACE_SECURITY_DEFAULT = 0
BS2_FACE_ENROLL_THRESHOLD_0 = 0
BS2_FACE_ENROLL_THRESHOLD_1 = 1
BS2_FACE_ENROLL_THRESHOLD_2 = 2
BS2_FACE_ENROLL_THRESHOLD_3 = 3
BS2_FACE_ENROLL_THRESHOLD_4 = 4
BS2_FACE_ENROLL_THRESHOLD_5 = 5
BS2_FACE_ENROLL_THRESHOLD_6 = 6
BS2_FACE_ENROLL_THRESHOLD_7 = 7
BS2_FACE_ENROLL_THRESHOLD_8 = 8
BS2_FACE_ENROLL_THRESHOLD_9 = 9
BS2_FACE_ENROLL_THRESHOLD_DEFAULT = 4
BS2_FACE_LIGHT_CONDITION_INDOOR = 0
BS2_FACE_LIGHT_CONDITION_OUTDOOR = 1
BS2_FACE_LIGHT_CONDITION_AUTO = 2
BS2_FACE_LIGHT_CONDITION_DARK = 3
BS2_FACE_LIGHT_CONDITION_DEFAULT = 0
BS2_FACE_DETECT_SENSITIVITY_OFF = 0
BS2_FACE_DETECT_SENSITIVITY_LOW = 1
BS2_FACE_DETECT_SENSITIVITY_MIDDLE = 2
BS2_FACE_DETECT_SENSITIVITY_HIGH = 3
BS2_FACE_DETECT_SENSITIVITY_DEFAULT = 2
BS2_FACE_LFD_LEVEL_OFF = 0
BS2_FACE_LFD_LEVEL_LOW = 1
BS2_FACE_LFD_LEVEL_MIDDLE = 2
BS2_FACE_LFD_LEVEL_HIGH = 3
BS2_FACE_LFD_LEVEL_DEFAULT = 0
BS2_FACE_PREVIEW_NONE = 0
BS2_FACE_PREVIEW_HALF = 1
BS2_FACE_PREVIEW_FULL = 2
BS2_FACE_PREVIEW_DEFAULT = 1



_FACEDATA = _descriptor.Descriptor(
  name='FaceData',
  full_name='face.FaceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='face.FaceData.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flag', full_name='face.FaceData.flag', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templates', full_name='face.FaceData.templates', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imageData', full_name='face.FaceData.imageData', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irTemplates', full_name='face.FaceData.irTemplates', index=4,
      number=7, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irImageData', full_name='face.FaceData.irImageData', index=5,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=150,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='face.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.ScanRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enrollThreshold', full_name='face.ScanRequest.enrollThreshold', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=235,
)


_SCANRESPONSE = _descriptor.Descriptor(
  name='ScanResponse',
  full_name='face.ScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='faceData', full_name='face.ScanResponse.faceData', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=285,
)


_EXTRACTREQUEST = _descriptor.Descriptor(
  name='ExtractRequest',
  full_name='face.ExtractRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.ExtractRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imageData', full_name='face.ExtractRequest.imageData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isWarped', full_name='face.ExtractRequest.isWarped', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=358,
)


_EXTRACTRESPONSE = _descriptor.Descriptor(
  name='ExtractResponse',
  full_name='face.ExtractResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templateData', full_name='face.ExtractResponse.templateData', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=399,
)


_NORMALIZEREQUEST = _descriptor.Descriptor(
  name='NormalizeRequest',
  full_name='face.NormalizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.NormalizeRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unwrappedImageData', full_name='face.NormalizeRequest.unwrappedImageData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=465,
)


_NORMALIZERESPONSE = _descriptor.Descriptor(
  name='NormalizeResponse',
  full_name='face.NormalizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wrappedImageData', full_name='face.NormalizeResponse.wrappedImageData', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=512,
)


_AUTHGROUP = _descriptor.Descriptor(
  name='AuthGroup',
  full_name='face.AuthGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='face.AuthGroup.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='face.AuthGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=551,
)


_GETAUTHGROUPREQUEST = _descriptor.Descriptor(
  name='GetAuthGroupRequest',
  full_name='face.GetAuthGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.GetAuthGroupRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=592,
)


_GETAUTHGROUPRESPONSE = _descriptor.Descriptor(
  name='GetAuthGroupResponse',
  full_name='face.GetAuthGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authGroups', full_name='face.GetAuthGroupResponse.authGroups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=653,
)


_ADDAUTHGROUPREQUEST = _descriptor.Descriptor(
  name='AddAuthGroupRequest',
  full_name='face.AddAuthGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.AddAuthGroupRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authGroups', full_name='face.AddAuthGroupRequest.authGroups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=731,
)


_ADDAUTHGROUPRESPONSE = _descriptor.Descriptor(
  name='AddAuthGroupResponse',
  full_name='face.AddAuthGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=755,
)


_ADDAUTHGROUPMULTIREQUEST = _descriptor.Descriptor(
  name='AddAuthGroupMultiRequest',
  full_name='face.AddAuthGroupMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='face.AddAuthGroupMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authGroups', full_name='face.AddAuthGroupMultiRequest.authGroups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=839,
)


_ADDAUTHGROUPMULTIRESPONSE = _descriptor.Descriptor(
  name='AddAuthGroupMultiResponse',
  full_name='face.AddAuthGroupMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='face.AddAuthGroupMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=910,
)


_DELETEAUTHGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteAuthGroupRequest',
  full_name='face.DeleteAuthGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.DeleteAuthGroupRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='face.DeleteAuthGroupRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=972,
)


_DELETEAUTHGROUPRESPONSE = _descriptor.Descriptor(
  name='DeleteAuthGroupResponse',
  full_name='face.DeleteAuthGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=999,
)


_DELETEAUTHGROUPMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAuthGroupMultiRequest',
  full_name='face.DeleteAuthGroupMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='face.DeleteAuthGroupMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='face.DeleteAuthGroupMultiRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1067,
)


_DELETEAUTHGROUPMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAuthGroupMultiResponse',
  full_name='face.DeleteAuthGroupMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='face.DeleteAuthGroupMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1141,
)


_DELETEALLAUTHGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteAllAuthGroupRequest',
  full_name='face.DeleteAllAuthGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.DeleteAllAuthGroupRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1188,
)


_DELETEALLAUTHGROUPRESPONSE = _descriptor.Descriptor(
  name='DeleteAllAuthGroupResponse',
  full_name='face.DeleteAllAuthGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1218,
)


_DELETEALLAUTHGROUPMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllAuthGroupMultiRequest',
  full_name='face.DeleteAllAuthGroupMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='face.DeleteAllAuthGroupMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1271,
)


_DELETEALLAUTHGROUPMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllAuthGroupMultiResponse',
  full_name='face.DeleteAllAuthGroupMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='face.DeleteAllAuthGroupMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1348,
)


_FACECONFIG = _descriptor.Descriptor(
  name='FaceConfig',
  full_name='face.FaceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='securityLevel', full_name='face.FaceConfig.securityLevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lightCondition', full_name='face.FaceConfig.lightCondition', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enrollThreshold', full_name='face.FaceConfig.enrollThreshold', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detectSensitivity', full_name='face.FaceConfig.detectSensitivity', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enrollTimeout', full_name='face.FaceConfig.enrollTimeout', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LFDLevel', full_name='face.FaceConfig.LFDLevel', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quickEnrollment', full_name='face.FaceConfig.quickEnrollment', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previewOption', full_name='face.FaceConfig.previewOption', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1351,
  serialized_end=1703,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='face.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1741,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='face.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='face.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1743,
  serialized_end=1796,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='face.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='face.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='face.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1798,
  serialized_end=1868,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='face.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1889,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='face.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='face.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='face.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1891,
  serialized_end=1967,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='face.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='face.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1969,
  serialized_end=2035,
)

_SCANREQUEST.fields_by_name['enrollThreshold'].enum_type = _FACEENROLLTHRESHOLD
_SCANRESPONSE.fields_by_name['faceData'].message_type = _FACEDATA
_GETAUTHGROUPRESPONSE.fields_by_name['authGroups'].message_type = _AUTHGROUP
_ADDAUTHGROUPREQUEST.fields_by_name['authGroups'].message_type = _AUTHGROUP
_ADDAUTHGROUPMULTIREQUEST.fields_by_name['authGroups'].message_type = _AUTHGROUP
_ADDAUTHGROUPMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEAUTHGROUPMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLAUTHGROUPMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_FACECONFIG.fields_by_name['securityLevel'].enum_type = _FACESECURITYLEVEL
_FACECONFIG.fields_by_name['lightCondition'].enum_type = _FACELIGHTCONDITION
_FACECONFIG.fields_by_name['enrollThreshold'].enum_type = _FACEENROLLTHRESHOLD
_FACECONFIG.fields_by_name['detectSensitivity'].enum_type = _FACEDETECTSENSITIVITY
_FACECONFIG.fields_by_name['LFDLevel'].enum_type = _FACELFDLEVEL
_FACECONFIG.fields_by_name['previewOption'].enum_type = _FACEPREVIEWOPTION
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _FACECONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _FACECONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _FACECONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['FaceData'] = _FACEDATA
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ScanResponse'] = _SCANRESPONSE
DESCRIPTOR.message_types_by_name['ExtractRequest'] = _EXTRACTREQUEST
DESCRIPTOR.message_types_by_name['ExtractResponse'] = _EXTRACTRESPONSE
DESCRIPTOR.message_types_by_name['NormalizeRequest'] = _NORMALIZEREQUEST
DESCRIPTOR.message_types_by_name['NormalizeResponse'] = _NORMALIZERESPONSE
DESCRIPTOR.message_types_by_name['AuthGroup'] = _AUTHGROUP
DESCRIPTOR.message_types_by_name['GetAuthGroupRequest'] = _GETAUTHGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetAuthGroupResponse'] = _GETAUTHGROUPRESPONSE
DESCRIPTOR.message_types_by_name['AddAuthGroupRequest'] = _ADDAUTHGROUPREQUEST
DESCRIPTOR.message_types_by_name['AddAuthGroupResponse'] = _ADDAUTHGROUPRESPONSE
DESCRIPTOR.message_types_by_name['AddAuthGroupMultiRequest'] = _ADDAUTHGROUPMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddAuthGroupMultiResponse'] = _ADDAUTHGROUPMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAuthGroupRequest'] = _DELETEAUTHGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteAuthGroupResponse'] = _DELETEAUTHGROUPRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAuthGroupMultiRequest'] = _DELETEAUTHGROUPMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAuthGroupMultiResponse'] = _DELETEAUTHGROUPMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllAuthGroupRequest'] = _DELETEALLAUTHGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllAuthGroupResponse'] = _DELETEALLAUTHGROUPRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllAuthGroupMultiRequest'] = _DELETEALLAUTHGROUPMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllAuthGroupMultiResponse'] = _DELETEALLAUTHGROUPMULTIRESPONSE
DESCRIPTOR.message_types_by_name['FaceConfig'] = _FACECONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['FaceFlag'] = _FACEFLAG
DESCRIPTOR.enum_types_by_name['FaceSecurityLevel'] = _FACESECURITYLEVEL
DESCRIPTOR.enum_types_by_name['FaceEnrollThreshold'] = _FACEENROLLTHRESHOLD
DESCRIPTOR.enum_types_by_name['FaceLightCondition'] = _FACELIGHTCONDITION
DESCRIPTOR.enum_types_by_name['FaceDetectSensitivity'] = _FACEDETECTSENSITIVITY
DESCRIPTOR.enum_types_by_name['FaceLFDLevel'] = _FACELFDLEVEL
DESCRIPTOR.enum_types_by_name['FacePreviewOption'] = _FACEPREVIEWOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FaceData = _reflection.GeneratedProtocolMessageType('FaceData', (_message.Message,), dict(
  DESCRIPTOR = _FACEDATA,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.FaceData)
  ))
_sym_db.RegisterMessage(FaceData)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCANREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.ScanRequest)
  ))
_sym_db.RegisterMessage(ScanRequest)

ScanResponse = _reflection.GeneratedProtocolMessageType('ScanResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCANRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.ScanResponse)
  ))
_sym_db.RegisterMessage(ScanResponse)

ExtractRequest = _reflection.GeneratedProtocolMessageType('ExtractRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.ExtractRequest)
  ))
_sym_db.RegisterMessage(ExtractRequest)

ExtractResponse = _reflection.GeneratedProtocolMessageType('ExtractResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXTRACTRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.ExtractResponse)
  ))
_sym_db.RegisterMessage(ExtractResponse)

NormalizeRequest = _reflection.GeneratedProtocolMessageType('NormalizeRequest', (_message.Message,), dict(
  DESCRIPTOR = _NORMALIZEREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.NormalizeRequest)
  ))
_sym_db.RegisterMessage(NormalizeRequest)

NormalizeResponse = _reflection.GeneratedProtocolMessageType('NormalizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _NORMALIZERESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.NormalizeResponse)
  ))
_sym_db.RegisterMessage(NormalizeResponse)

AuthGroup = _reflection.GeneratedProtocolMessageType('AuthGroup', (_message.Message,), dict(
  DESCRIPTOR = _AUTHGROUP,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.AuthGroup)
  ))
_sym_db.RegisterMessage(AuthGroup)

GetAuthGroupRequest = _reflection.GeneratedProtocolMessageType('GetAuthGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETAUTHGROUPREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.GetAuthGroupRequest)
  ))
_sym_db.RegisterMessage(GetAuthGroupRequest)

GetAuthGroupResponse = _reflection.GeneratedProtocolMessageType('GetAuthGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETAUTHGROUPRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.GetAuthGroupResponse)
  ))
_sym_db.RegisterMessage(GetAuthGroupResponse)

AddAuthGroupRequest = _reflection.GeneratedProtocolMessageType('AddAuthGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDAUTHGROUPREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.AddAuthGroupRequest)
  ))
_sym_db.RegisterMessage(AddAuthGroupRequest)

AddAuthGroupResponse = _reflection.GeneratedProtocolMessageType('AddAuthGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDAUTHGROUPRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.AddAuthGroupResponse)
  ))
_sym_db.RegisterMessage(AddAuthGroupResponse)

AddAuthGroupMultiRequest = _reflection.GeneratedProtocolMessageType('AddAuthGroupMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDAUTHGROUPMULTIREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.AddAuthGroupMultiRequest)
  ))
_sym_db.RegisterMessage(AddAuthGroupMultiRequest)

AddAuthGroupMultiResponse = _reflection.GeneratedProtocolMessageType('AddAuthGroupMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDAUTHGROUPMULTIRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.AddAuthGroupMultiResponse)
  ))
_sym_db.RegisterMessage(AddAuthGroupMultiResponse)

DeleteAuthGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteAuthGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEAUTHGROUPREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAuthGroupRequest)
  ))
_sym_db.RegisterMessage(DeleteAuthGroupRequest)

DeleteAuthGroupResponse = _reflection.GeneratedProtocolMessageType('DeleteAuthGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEAUTHGROUPRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAuthGroupResponse)
  ))
_sym_db.RegisterMessage(DeleteAuthGroupResponse)

DeleteAuthGroupMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAuthGroupMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEAUTHGROUPMULTIREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAuthGroupMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAuthGroupMultiRequest)

DeleteAuthGroupMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAuthGroupMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEAUTHGROUPMULTIRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAuthGroupMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAuthGroupMultiResponse)

DeleteAllAuthGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteAllAuthGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLAUTHGROUPREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAllAuthGroupRequest)
  ))
_sym_db.RegisterMessage(DeleteAllAuthGroupRequest)

DeleteAllAuthGroupResponse = _reflection.GeneratedProtocolMessageType('DeleteAllAuthGroupResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLAUTHGROUPRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAllAuthGroupResponse)
  ))
_sym_db.RegisterMessage(DeleteAllAuthGroupResponse)

DeleteAllAuthGroupMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllAuthGroupMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLAUTHGROUPMULTIREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAllAuthGroupMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllAuthGroupMultiRequest)

DeleteAllAuthGroupMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllAuthGroupMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLAUTHGROUPMULTIRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.DeleteAllAuthGroupMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllAuthGroupMultiResponse)

FaceConfig = _reflection.GeneratedProtocolMessageType('FaceConfig', (_message.Message,), dict(
  DESCRIPTOR = _FACECONFIG,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.FaceConfig)
  ))
_sym_db.RegisterMessage(FaceConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'face_pb2'
  # @@protoc_insertion_point(class_scope:face.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None
_FACESECURITYLEVEL._options = None
_FACEENROLLTHRESHOLD._options = None
_FACELIGHTCONDITION._options = None
_FACEDETECTSENSITIVITY._options = None
_FACELFDLEVEL._options = None
_FACEPREVIEWOPTION._options = None

_FACE = _descriptor.ServiceDescriptor(
  name='Face',
  full_name='face.Face',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3385,
  serialized_end=4353,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='face.Face.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_SCANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Extract',
    full_name='face.Face.Extract',
    index=1,
    containing_service=None,
    input_type=_EXTRACTREQUEST,
    output_type=_EXTRACTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Normalize',
    full_name='face.Face.Normalize',
    index=2,
    containing_service=None,
    input_type=_NORMALIZEREQUEST,
    output_type=_NORMALIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='face.Face.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='face.Face.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='face.Face.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthGroup',
    full_name='face.Face.GetAuthGroup',
    index=6,
    containing_service=None,
    input_type=_GETAUTHGROUPREQUEST,
    output_type=_GETAUTHGROUPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddAuthGroup',
    full_name='face.Face.AddAuthGroup',
    index=7,
    containing_service=None,
    input_type=_ADDAUTHGROUPREQUEST,
    output_type=_ADDAUTHGROUPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddAuthGroupMulti',
    full_name='face.Face.AddAuthGroupMulti',
    index=8,
    containing_service=None,
    input_type=_ADDAUTHGROUPMULTIREQUEST,
    output_type=_ADDAUTHGROUPMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAuthGroup',
    full_name='face.Face.DeleteAuthGroup',
    index=9,
    containing_service=None,
    input_type=_DELETEAUTHGROUPREQUEST,
    output_type=_DELETEAUTHGROUPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAuthGroupMulti',
    full_name='face.Face.DeleteAuthGroupMulti',
    index=10,
    containing_service=None,
    input_type=_DELETEAUTHGROUPMULTIREQUEST,
    output_type=_DELETEAUTHGROUPMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllAuthGroup',
    full_name='face.Face.DeleteAllAuthGroup',
    index=11,
    containing_service=None,
    input_type=_DELETEALLAUTHGROUPREQUEST,
    output_type=_DELETEALLAUTHGROUPRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllAuthGroupMulti',
    full_name='face.Face.DeleteAllAuthGroupMulti',
    index=12,
    containing_service=None,
    input_type=_DELETEALLAUTHGROUPMULTIREQUEST,
    output_type=_DELETEALLAUTHGROUPMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FACE)

DESCRIPTOR.services_by_name['Face'] = _FACE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import event_pb2 as event__pb2


class EventStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.EnableMonitoring = channel.unary_unary(
        '/event.Event/EnableMonitoring',
        request_serializer=event__pb2.EnableMonitoringRequest.SerializeToString,
        response_deserializer=event__pb2.EnableMonitoringResponse.FromString,
        )
    self.EnableMonitoringMulti = channel.unary_unary(
        '/event.Event/EnableMonitoringMulti',
        request_serializer=event__pb2.EnableMonitoringMultiRequest.SerializeToString,
        response_deserializer=event__pb2.EnableMonitoringMultiResponse.FromString,
        )
    self.DisableMonitoring = channel.unary_unary(
        '/event.Event/DisableMonitoring',
        request_serializer=event__pb2.DisableMonitoringRequest.SerializeToString,
        response_deserializer=event__pb2.DisableMonitoringResponse.FromString,
        )
    self.DisableMonitoringMulti = channel.unary_unary(
        '/event.Event/DisableMonitoringMulti',
        request_serializer=event__pb2.DisableMonitoringMultiRequest.SerializeToString,
        response_deserializer=event__pb2.DisableMonitoringMultiResponse.FromString,
        )
    self.SubscribeRealtimeLog = channel.unary_stream(
        '/event.Event/SubscribeRealtimeLog',
        request_serializer=event__pb2.SubscribeRealtimeLogRequest.SerializeToString,
        response_deserializer=event__pb2.EventLog.FromString,
        )
    self.GetLog = channel.unary_unary(
        '/event.Event/GetLog',
        request_serializer=event__pb2.GetLogRequest.SerializeToString,
        response_deserializer=event__pb2.GetLogResponse.FromString,
        )
    self.GetLogWithFilter = channel.unary_unary(
        '/event.Event/GetLogWithFilter',
        request_serializer=event__pb2.GetLogWithFilterRequest.SerializeToString,
        response_deserializer=event__pb2.GetLogWithFilterResponse.FromString,
        )
    self.GetImageLog = channel.unary_unary(
        '/event.Event/GetImageLog',
        request_serializer=event__pb2.GetImageLogRequest.SerializeToString,
        response_deserializer=event__pb2.GetImageLogResponse.FromString,
        )
    self.GetImageFilter = channel.unary_unary(
        '/event.Event/GetImageFilter',
        request_serializer=event__pb2.GetImageFilterRequest.SerializeToString,
        response_deserializer=event__pb2.GetImageFilterResponse.FromString,
        )
    self.SetImageFilter = channel.unary_unary(
        '/event.Event/SetImageFilter',
        request_serializer=event__pb2.SetImageFilterRequest.SerializeToString,
        response_deserializer=event__pb2.SetImageFilterResponse.FromString,
        )
    self.SetImageFilterMulti = channel.unary_unary(
        '/event.Event/SetImageFilterMulti',
        request_serializer=event__pb2.SetImageFilterMultiRequest.SerializeToString,
        response_deserializer=event__pb2.SetImageFilterMultiResponse.FromString,
        )
    self.ClearLog = channel.unary_unary(
        '/event.Event/ClearLog',
        request_serializer=event__pb2.ClearLogRequest.SerializeToString,
        response_deserializer=event__pb2.ClearLogResponse.FromString,
        )
    self.ClearLogMulti = channel.unary_unary(
        '/event.Event/ClearLogMulti',
        request_serializer=event__pb2.ClearLogMultiRequest.SerializeToString,
        response_deserializer=event__pb2.ClearLogMultiResponse.FromString,
        )


class EventServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def EnableMonitoring(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EnableMonitoringMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DisableMonitoring(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DisableMonitoringMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeRealtimeLog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLogWithFilter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetImageLog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetImageFilter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetImageFilter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetImageFilterMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearLog(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearLogMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_EventServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'EnableMonitoring': grpc.unary_unary_rpc_method_handler(
          servicer.EnableMonitoring,
          request_deserializer=event__pb2.EnableMonitoringRequest.FromString,
          response_serializer=event__pb2.EnableMonitoringResponse.SerializeToString,
      ),
      'EnableMonitoringMulti': grpc.unary_unary_rpc_method_handler(
          servicer.EnableMonitoringMulti,
          request_deserializer=event__pb2.EnableMonitoringMultiRequest.FromString,
          response_serializer=event__pb2.EnableMonitoringMultiResponse.SerializeToString,
      ),
      'DisableMonitoring': grpc.unary_unary_rpc_method_handler(
          servicer.DisableMonitoring,
          request_deserializer=event__pb2.DisableMonitoringRequest.FromString,
          response_serializer=event__pb2.DisableMonitoringResponse.SerializeToString,
      ),
      'DisableMonitoringMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DisableMonitoringMulti,
          request_deserializer=event__pb2.DisableMonitoringMultiRequest.FromString,
          response_serializer=event__pb2.DisableMonitoringMultiResponse.SerializeToString,
      ),
      'SubscribeRealtimeLog': grpc.unary_stream_rpc_method_handler(
          servicer.SubscribeRealtimeLog,
          request_deserializer=event__pb2.SubscribeRealtimeLogRequest.FromString,
          response_serializer=event__pb2.EventLog.SerializeToString,
      ),
      'GetLog': grpc.unary_unary_rpc_method_handler(
          servicer.GetLog,
          request_deserializer=event__pb2.GetLogRequest.FromString,
          response_serializer=event__pb2.GetLogResponse.SerializeToString,
      ),
      'GetLogWithFilter': grpc.unary_unary_rpc_method_handler(
          servicer.GetLogWithFilter,
          request_deserializer=event__pb2.GetLogWithFilterRequest.FromString,
          response_serializer=event__pb2.GetLogWithFilterResponse.SerializeToString,
      ),
      'GetImageLog': grpc.unary_unary_rpc_method_handler(
          servicer.GetImageLog,
          request_deserializer=event__pb2.GetImageLogRequest.FromString,
          response_serializer=event__pb2.GetImageLogResponse.SerializeToString,
      ),
      'GetImageFilter': grpc.unary_unary_rpc_method_handler(
          servicer.GetImageFilter,
          request_deserializer=event__pb2.GetImageFilterRequest.FromString,
          response_serializer=event__pb2.GetImageFilterResponse.SerializeToString,
      ),
      'SetImageFilter': grpc.unary_unary_rpc_method_handler(
          servicer.SetImageFilter,
          request_deserializer=event__pb2.SetImageFilterRequest.FromString,
          response_serializer=event__pb2.SetImageFilterResponse.SerializeToString,
      ),
      'SetImageFilterMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetImageFilterMulti,
          request_deserializer=event__pb2.SetImageFilterMultiRequest.FromString,
          response_serializer=event__pb2.SetImageFilterMultiResponse.SerializeToString,
      ),
      'ClearLog': grpc.unary_unary_rpc_method_handler(
          servicer.ClearLog,
          request_deserializer=event__pb2.ClearLogRequest.FromString,
          response_serializer=event__pb2.ClearLogResponse.SerializeToString,
      ),
      'ClearLogMulti': grpc.unary_unary_rpc_method_handler(
          servicer.ClearLogMulti,
          request_deserializer=event__pb2.ClearLogMultiRequest.FromString,
          response_serializer=event__pb2.ClearLogMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'event.Event', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import input_pb2 as input__pb2


class InputStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetConfig = channel.unary_unary(
        '/input.Input/GetConfig',
        request_serializer=input__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=input__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/input.Input/SetConfig',
        request_serializer=input__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=input__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/input.Input/SetConfigMulti',
        request_serializer=input__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=input__pb2.SetConfigMultiResponse.FromString,
        )


class InputServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_InputServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=input__pb2.GetConfigRequest.FromString,
          response_serializer=input__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=input__pb2.SetConfigRequest.FromString,
          response_serializer=input__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=input__pb2.SetConfigMultiRequest.FromString,
          response_serializer=input__pb2.SetConfigMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'input.Input', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interlock_zone.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import zone_pb2 as zone__pb2
from biostarPython.service import action_pb2 as action__pb2
from biostarPython.service import device_pb2 as device__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='interlock_zone.proto',
  package='interlock_zone',
  syntax='proto3',
  serialized_options=_b('\n!com.supremainc.sdk.interlock_zoneP\001Z\035biostar/service/interlockZone'),
  serialized_pb=_b('\n\x14interlock_zone.proto\x12\x0einterlock_zone\x1a\nzone.proto\x1a\x0c\x61\x63tion.proto\x1a\x0c\x64\x65vice.proto\"t\n\x05Input\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\x12&\n\nswitchType\x18\x03 \x01(\x0e\x32\x12.device.SwitchType\x12\x10\n\x08\x64uration\x18\x04 \x01(\r\x12\x11\n\toperation\x18\x05 \x01(\r\"7\n\x06Output\x12\r\n\x05\x65vent\x18\x01 \x01(\r\x12\x1e\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32\x0e.action.Action\"\x9b\x01\n\x08ZoneInfo\x12\x0e\n\x06zoneID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12%\n\x06inputs\x18\x04 \x03(\x0b\x32\x15.interlock_zone.Input\x12\'\n\x07outputs\x18\x05 \x03(\x0b\x32\x16.interlock_zone.Output\x12\x0f\n\x07\x64oorIDs\x18\x06 \x03(\r\"\x1e\n\nGetRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"6\n\x0bGetResponse\x12\'\n\x05zones\x18\x01 \x03(\x0b\x32\x18.interlock_zone.ZoneInfo\"5\n\x10GetStatusRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0f\n\x07zoneIDs\x18\x02 \x03(\r\"5\n\x11GetStatusResponse\x12 \n\x06status\x18\x01 \x03(\x0b\x32\x10.zone.ZoneStatus\"G\n\nAddRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\'\n\x05zones\x18\x02 \x03(\x0b\x32\x18.interlock_zone.ZoneInfo\"\r\n\x0b\x41\x64\x64Response\"2\n\rDeleteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0f\n\x07zoneIDs\x18\x02 \x03(\r\"\x10\n\x0e\x44\x65leteResponse\"$\n\x10\x44\x65leteAllRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x44\x65leteAllResponse\"E\n\x0fSetAlarmRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0f\n\x07zoneIDs\x18\x02 \x03(\r\x12\x0f\n\x07\x61larmed\x18\x03 \x01(\x08\"\x12\n\x10SetAlarmResponse*`\n\rOperationType\x12\x12\n\x0eOPERATION_NONE\x10\x00\x12\x13\n\x0fOPERATION_ENRTY\x10\x01\x12\x12\n\x0eOPERATION_EXIT\x10\x02\x12\x12\n\rOPERATION_ALL\x10\xff\x01\x32\xcb\x03\n\rInterlockZone\x12>\n\x03Get\x12\x1a.interlock_zone.GetRequest\x1a\x1b.interlock_zone.GetResponse\x12P\n\tGetStatus\x12 .interlock_zone.GetStatusRequest\x1a!.interlock_zone.GetStatusResponse\x12>\n\x03\x41\x64\x64\x12\x1a.interlock_zone.AddRequest\x1a\x1b.interlock_zone.AddResponse\x12G\n\x06\x44\x65lete\x12\x1d.interlock_zone.DeleteRequest\x1a\x1e.interlock_zone.DeleteResponse\x12P\n\tDeleteAll\x12 .interlock_zone.DeleteAllRequest\x1a!.interlock_zone.DeleteAllResponse\x12M\n\x08SetAlarm\x12\x1f.interlock_zone.SetAlarmRequest\x1a .interlock_zone.SetAlarmResponseBD\n!com.supremainc.sdk.interlock_zoneP\x01Z\x1d\x62iostar/service/interlockZoneb\x06proto3')
  ,
  dependencies=[zone__pb2.DESCRIPTOR,action__pb2.DESCRIPTOR,device__pb2.DESCRIPTOR,])

_OPERATIONTYPE = _descriptor.EnumDescriptor(
  name='OperationType',
  full_name='interlock_zone.OperationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPERATION_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_ENRTY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_EXIT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPERATION_ALL', index=3, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=919,
  serialized_end=1015,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONTYPE)

OperationType = enum_type_wrapper.EnumTypeWrapper(_OPERATIONTYPE)
OPERATION_NONE = 0
OPERATION_ENRTY = 1
OPERATION_EXIT = 2
OPERATION_ALL = 255



_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='interlock_zone.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.Input.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='interlock_zone.Input.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='switchType', full_name='interlock_zone.Input.switchType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='interlock_zone.Input.duration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='interlock_zone.Input.operation', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=196,
)


_OUTPUT = _descriptor.Descriptor(
  name='Output',
  full_name='interlock_zone.Output',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='interlock_zone.Output.event', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='interlock_zone.Output.action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=253,
)


_ZONEINFO = _descriptor.Descriptor(
  name='ZoneInfo',
  full_name='interlock_zone.ZoneInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zoneID', full_name='interlock_zone.ZoneInfo.zoneID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='interlock_zone.ZoneInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='interlock_zone.ZoneInfo.disabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='interlock_zone.ZoneInfo.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='interlock_zone.ZoneInfo.outputs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doorIDs', full_name='interlock_zone.ZoneInfo.doorIDs', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=411,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='interlock_zone.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.GetRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=443,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='interlock_zone.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zones', full_name='interlock_zone.GetResponse.zones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=499,
)


_GETSTATUSREQUEST = _descriptor.Descriptor(
  name='GetStatusRequest',
  full_name='interlock_zone.GetStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.GetStatusRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoneIDs', full_name='interlock_zone.GetStatusRequest.zoneIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=554,
)


_GETSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetStatusResponse',
  full_name='interlock_zone.GetStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='interlock_zone.GetStatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=609,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='interlock_zone.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.AddRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zones', full_name='interlock_zone.AddRequest.zones', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=682,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='interlock_zone.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=697,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='interlock_zone.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.DeleteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoneIDs', full_name='interlock_zone.DeleteRequest.zoneIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=749,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='interlock_zone.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=767,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='interlock_zone.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.DeleteAllRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=805,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='interlock_zone.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=826,
)


_SETALARMREQUEST = _descriptor.Descriptor(
  name='SetAlarmRequest',
  full_name='interlock_zone.SetAlarmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='interlock_zone.SetAlarmRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoneIDs', full_name='interlock_zone.SetAlarmRequest.zoneIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarmed', full_name='interlock_zone.SetAlarmRequest.alarmed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=897,
)


_SETALARMRESPONSE = _descriptor.Descriptor(
  name='SetAlarmResponse',
  full_name='interlock_zone.SetAlarmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=899,
  serialized_end=917,
)

_INPUT.fields_by_name['switchType'].enum_type = device__pb2._SWITCHTYPE
_OUTPUT.fields_by_name['action'].message_type = action__pb2._ACTION
_ZONEINFO.fields_by_name['inputs'].message_type = _INPUT
_ZONEINFO.fields_by_name['outputs'].message_type = _OUTPUT
_GETRESPONSE.fields_by_name['zones'].message_type = _ZONEINFO
_GETSTATUSRESPONSE.fields_by_name['status'].message_type = zone__pb2._ZONESTATUS
_ADDREQUEST.fields_by_name['zones'].message_type = _ZONEINFO
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['Output'] = _OUTPUT
DESCRIPTOR.message_types_by_name['ZoneInfo'] = _ZONEINFO
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['GetStatusRequest'] = _GETSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetStatusResponse'] = _GETSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['SetAlarmRequest'] = _SETALARMREQUEST
DESCRIPTOR.message_types_by_name['SetAlarmResponse'] = _SETALARMRESPONSE
DESCRIPTOR.enum_types_by_name['OperationType'] = _OPERATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), dict(
  DESCRIPTOR = _INPUT,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.Input)
  ))
_sym_db.RegisterMessage(Input)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUT,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.Output)
  ))
_sym_db.RegisterMessage(Output)

ZoneInfo = _reflection.GeneratedProtocolMessageType('ZoneInfo', (_message.Message,), dict(
  DESCRIPTOR = _ZONEINFO,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.ZoneInfo)
  ))
_sym_db.RegisterMessage(ZoneInfo)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATUSREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.GetStatusRequest)
  ))
_sym_db.RegisterMessage(GetStatusRequest)

GetStatusResponse = _reflection.GeneratedProtocolMessageType('GetStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATUSRESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.GetStatusResponse)
  ))
_sym_db.RegisterMessage(GetStatusResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.DeleteAllRequest)
  ))
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLRESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.DeleteAllResponse)
  ))
_sym_db.RegisterMessage(DeleteAllResponse)

SetAlarmRequest = _reflection.GeneratedProtocolMessageType('SetAlarmRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETALARMREQUEST,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.SetAlarmRequest)
  ))
_sym_db.RegisterMessage(SetAlarmRequest)

SetAlarmResponse = _reflection.GeneratedProtocolMessageType('SetAlarmResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETALARMRESPONSE,
  __module__ = 'interlock_zone_pb2'
  # @@protoc_insertion_point(class_scope:interlock_zone.SetAlarmResponse)
  ))
_sym_db.RegisterMessage(SetAlarmResponse)


DESCRIPTOR._options = None

_INTERLOCKZONE = _descriptor.ServiceDescriptor(
  name='InterlockZone',
  full_name='interlock_zone.InterlockZone',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1018,
  serialized_end=1477,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='interlock_zone.InterlockZone.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStatus',
    full_name='interlock_zone.InterlockZone.GetStatus',
    index=1,
    containing_service=None,
    input_type=_GETSTATUSREQUEST,
    output_type=_GETSTATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='interlock_zone.InterlockZone.Add',
    index=2,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='interlock_zone.InterlockZone.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='interlock_zone.InterlockZone.DeleteAll',
    index=4,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetAlarm',
    full_name='interlock_zone.InterlockZone.SetAlarm',
    index=5,
    containing_service=None,
    input_type=_SETALARMREQUEST,
    output_type=_SETALARMRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTERLOCKZONE)

DESCRIPTOR.services_by_name['InterlockZone'] = _INTERLOCKZONE

# @@protoc_insertion_point(module_scope)
